@@ -205,6 +205,10 @@ AbstractLogView::AbstractLogView(const AbstractLogData* newLogData,
             this, SLOT ( handlePatternUpdated() ) );
     connect( verticalScrollBar(), SIGNAL( sliderMoved( int ) ),
             this, SIGNAL( followDisabled() ) );
+    connect( &quickFind_, SIGNAL( notify( const QString& ) ),
+            this, SIGNAL( notifyQuickFind( const QString& ) ) );
+    connect( &quickFind_, SIGNAL( clearNotification() ),
+            this, SIGNAL( clearQuickFindNotification() ) );
 }
 
 AbstractLogView::~AbstractLogView()
@@ -957,7 +961,7 @@ inline bool AbstractLogView::isCharWord( char c )
 void AbstractLogView::selectWordAtPosition( const QPoint& pos )
 {
     const int x = pos.x();
-    const QString line = logData->getLineString( pos.y() );
+    const QString line = logData->getExpandedLineString( pos.y() );
 
     if ( isCharWord( line[x].toLatin1() ) ) {
         // Search backward for the first character in the word
